@@ -1,10 +1,10 @@
-from .annotated import annotated_arg
+from .named import named_arg
 from .bindings import AbstractModule, ClassBinding, InstanceBinding, ItemBinding, Module, MultiBinding, PrivateModule, \
     ProviderBinding, SelfBinding
-from .exceptions import AnnotationError, BindingError, InjectException, NoBindingFound, NonInjectableTypeError
+from .exceptions import NamedError, BindingError, InjectException, NoBindingFound, NonInjectableTypeError
 from .injector import Injector
 from .injector_options import InjectorOptions
 from .provider import Provider
 from .scopes import ImmediateScope, PerLookupScope, SingletonScope, ThreadScope
 from .target import Target
-from .typings import InjectedT
+from .utils import InjectedT
