@@ -1,7 +1,7 @@
 from typing import Dict, List, Optional, Type
 
 from opyoid.provider import Provider
-from opyoid.typings import InjectedT
+from opyoid.utils import InjectedT
 
 
 class FromClassProvider(Provider[InjectedT]):
