@@ -1,7 +1,6 @@
-from opyoid.injection_state import InjectionState
+from opyoid.injection_context import InjectionContext
 from opyoid.provider import Provider
-from opyoid.target import Target
-from opyoid.typings import InjectedT
+from opyoid.utils import InjectedT
 
 
 class ProviderFactory:
@@ -10,10 +9,10 @@ class ProviderFactory:
     A target corresponds to either a Binding target or a dependency of a Binding target.
     """
 
-    def accept(self, target: Target[InjectedT], state: InjectionState) -> bool:
+    def accept(self, context: InjectionContext[InjectedT]) -> bool:
         """Returns True if this factory can handle this target."""
         raise NotImplementedError
 
-    def create(self, target: Target[InjectedT], state: InjectionState) -> Provider[InjectedT]:
+    def create(self, context: InjectionContext[InjectedT]) -> Provider[InjectedT]:
         """Returns the provider corresponding to this target."""
         raise NotImplementedError
